@@ -68,17 +68,6 @@ class RefcountStoreTests(unittest.TestCase):
         self.rs.set_refcount(123, 1)
         self.assertEqual(self.rs.get_refcount(123), 1)
 
-    def test_does_not_set_refcount_if_zero(self):
-        self.rs.set_refcount(123, 0)
-        self.assertFalse(123 in self.rs.refcounts)
-        self.assertEqual(self.rs.get_refcount(123), 0)
-
-    def test_removes_refcount_that_drops_to_zero(self):
-        self.rs.set_refcount(123, 1)
-        self.rs.set_refcount(123, 0)
-        self.assertFalse(123 in self.rs.refcounts)
-        self.assertEqual(self.rs.get_refcount(123), 0)
-
     def test_updates_refcount(self):
         self.rs.set_refcount(123, 1)
         self.rs.set_refcount(123, 2)
@@ -102,8 +91,8 @@ class RefcountStoreTests(unittest.TestCase):
         refs = range(2048)
         for ref in refs:
             self.rs.set_refcount(ref, ref)
-        encoded = larch.refcountstore.encode_refcounts(self.rs.refcounts, 
-                                                       0, 1024)
+        encoded = larch.refcountstore.encode_refcounts(
+            self.rs.refcounts, 0, 1024, range(1024))
         decoded = larch.refcountstore.decode_refcounts(encoded)
         self.assertEqual(decoded, [(x, x) for x in refs[:1024]])
 
